@@ -6,7 +6,9 @@ from myst.core.data.time_array import TimeArray
 from myst.core.time.time import Time
 from myst.core.time.time_delta import TimeDelta
 from myst.models.timing import AbsoluteTiming, CronTiming, RelativeTiming
+from myst.resources import hpo
 from myst.resources.backtest import Backtest, BacktestJob
+from myst.resources.hpo import HPO
 from myst.resources.input import Input
 from myst.resources.layer import Layer
 from myst.resources.model import Model
@@ -29,6 +31,7 @@ __all__ = [
     "get_client",
     "set_client",
     "Backtest",
+    "HPO",
     "CronTiming",
     "Input",
     "Layer",
@@ -45,4 +48,5 @@ __all__ = [
     "TimeDelta",
     "TimeSeries",
     "TimeSeriesRunPolicy",
+    "hpo",
 ]
