@@ -1,7 +1,9 @@
 from functools import singledispatch
-from typing import Any, List, Mapping, Tuple, Union
+from typing import Any, List, Mapping, Optional, Tuple, TypeVar, Union
 from uuid import UUID
 
+from myst.adapters.utils import _Unset
+
 UUIDOrStr = Union[str, UUID]
 IntOrStr = Union[int, str]
 Shape = Tuple[int, ...]
@@ -9,6 +11,9 @@ CoordinateLabels = Tuple[Tuple[IntOrStr, ...], ...]
 AxisLabels = Tuple[IntOrStr, ...]
 Metadata = Mapping[str, Union[str, int, float, bool, None]]
 
+T = TypeVar("T")
+OptionalParam = Union[Optional[T], _Unset]
+
 # Note: This should be a recursive type alias but `mypy` doesn't support that, so use `List[Any]` instead to allow for
 #   an arbitrary amount of nesting.
 ItemOrSlice = Union[Tuple[Union[IntOrStr, List[Any]], ...], List[Any], IntOrStr]
