@@ -1,5 +1,3 @@
-from typing import Optional
-
 from pydantic import Field
 from typing_extensions import Literal
 
@@ -12,7 +10,5 @@ class BacktestJobGet(base_model.BaseModel):
 
     object_: Literal["BacktestJob"] = Field(..., alias="object")
     uuid: str
-    create_time: str
     backtest: str
     state: JobState
-    update_time: Optional[str] = None
