@@ -218,6 +218,41 @@ def example_backtest(example_project: Dict[str, Any], example_model: Dict[str, A
     )
 
 
+@pytest.fixture
+def example_hpo(example_project: Dict[str, Any], example_model: Dict[str, Any]) -> Dict[str, Any]:
+    fit_start_timing_str = "-P1Y"
+    fit_end_timing_str = "PT0H"
+    predict_start_timing_str = "PT1H"
+    predict_end_timing_str = "PT6H"
+
+    return dict(
+        object="HPO",
+        uuid="c72c0a3d-7690-4b22-bafb-267437a1e648",
+        project=example_project["uuid"],
+        create_time="2021-09-15T22:36:44Z",
+        update_time=None,
+        creator="fb80ae8a-dc73-45f3-9a49-ca57202b8fdf",
+        owner="fb80ae8a-dc73-45f3-9a49-ca57202b8fdf",
+        title="example_hpo",
+        description=None,
+        model=example_model["uuid"],
+        test_start_time="2020-01-01T00:00:00Z",
+        test_end_time="2021-01-01T00:00:00Z",
+        fit_start_timing=dict(object="Timing", type="RelativeTiming", offset=fit_start_timing_str, time_zone=None),
+        fit_end_timing=dict(object="Timing", type="RelativeTiming", offset=fit_end_timing_str, time_zone=None),
+        fit_reference_timing=dict(object="Timing", type="CronTiming", cron_expression="0 0 * * 0", time_zone="UTC"),
+        predict_start_timing=dict(
+            object="Timing", type="RelativeTiming", offset=predict_start_timing_str, time_zone="UTC"
+        ),
+        predict_end_timing=dict(object="Timing", type="RelativeTiming", offset=predict_end_timing_str, time_zone="UTC"),
+        predict_reference_timing=dict(object="Timing", type="CronTiming", cron_expression="0 * * * *", time_zone="UTC"),
+        search_algorithm=dict(
+            object="SearchAlgorithm", type="Hyperopt", metric="mse", num_trials=12, max_concurrent_trials=3
+        ),
+        search_space=dict(max_depth=dict(object="Sampler", type="Uniform", lower=1, upper=12)),
+    )
+
+
 @pytest.fixture
 def example_result() -> Dict[str, Any]:
     return dict(
@@ -229,3 +264,32 @@ def example_result() -> Dict[str, Any]:
         result_url="https://storage.cloud.google.com/backtest-result/37faf8b5-5a4e-40e5-b90a-439a9743f921.json",
         metrics=dict(mape=1.4, mae=43, rmse=1.39348),
     )
+
+
+@pytest.fixture
+def example_hpo_result() -> Dict[str, Any]:
+    return dict(
+        data=[
+            dict(
+                object="HPOResult",
+                uuid="37faf8b5-5a4e-40e5-b90a-439a9743f921",
+                create_time="2021-03-17T00:00:09Z",
+                metric="mse",
+                best_trial=dict(parameters=dict(p1=3, p2=4), metrics=dict(mae=1.4, mse=43, rmse=1.39348)),
+            )
+        ],
+        has_more=False,
+    )
+
+
+@pytest.fixture
+def example_hpo_job(example_hpo: Dict[str, Any]) -> Dict[str, Any]:
+    return dict(
+        object="HPOJob",
+        uuid="c72c0a3d-7690-4b22-bafb-267437a1e647",
+        hpo=example_hpo["uuid"],
+        state="SUCCESS",
+        create_time="2021-03-17T00:00:09Z",
+        schedule_time="2021-03-17T00:00:09Z",
+        num_trials_completed=0,
+    )
