@@ -8,15 +8,17 @@ from myst.core.time.time_delta import TimeDelta
 from myst.models.time_dataset import TimeDataset, TimeDatasetRow
 from myst.models.timing import ScheduleTiming, TimeRangeBoundary, from_schedule_specifier, from_time_range_boundary
 from myst.models.types import AxisLabels, CoordinateLabels, ItemOrSlice, Shape, UUIDOrStr, to_uuid
-from myst.openapi.api.time_series import (
+from myst.openapi.api.projects.time_series import (
     create_time_series,
-    create_time_series_run_policy,
     get_time_series,
     insert_time_series_data,
-    list_time_series_layers,
-    list_time_series_run_policies,
     query_time_series_data,
 )
+from myst.openapi.api.projects.time_series.layers import list_time_series_layers
+from myst.openapi.api.projects.time_series.run_policies import (
+    create_time_series_run_policy,
+    list_time_series_run_policies,
+)
 from myst.openapi.models.time_series_create import TimeSeriesCreate
 from myst.openapi.models.time_series_insert import TimeSeriesInsert
 from myst.openapi.models.time_series_run_policy_create import TimeSeriesRunPolicyCreate
@@ -78,11 +80,11 @@ class TimeSeries(Node):
         """
         time_series = create_time_series.request_sync(
             client=get_client(),
+            project_uuid=str(project.uuid),
             json_body=TimeSeriesCreate(
                 object="Node",
                 type="TimeSeries",
                 title=title,
-                project=str(project.uuid),
                 sample_period=sample_period.to_iso_string(),
                 cell_shape=cell_shape,
                 coordinate_labels=coordinate_labels,
@@ -115,9 +117,11 @@ class TimeSeries(Node):
         return recipe.create(project=project, title=title, description=description)
 
     @classmethod
-    def get(cls, uuid: UUIDOrStr) -> "TimeSeries":
+    def get(cls, project_uuid: UUIDOrStr, uuid: UUIDOrStr) -> "TimeSeries":
         """Gets a specific time series by its identifier."""
-        time_series = get_time_series.request_sync(client=get_client(), uuid=str(to_uuid(uuid)))
+        time_series = get_time_series.request_sync(
+            client=get_client(), project_uuid=str(to_uuid(project_uuid)), uuid=str(to_uuid(uuid))
+        )
 
         return TimeSeries.parse_obj(time_series.dict())
 
@@ -147,7 +151,10 @@ class TimeSeries(Node):
         )
 
         insert_time_series_data.request_sync(
-            client=get_client(), uuid=str(self.uuid), json_body=TimeSeriesInsert(time_dataset=time_dataset)
+            client=get_client(),
+            project_uuid=str(self.project),
+            uuid=str(self.uuid),
+            json_body=TimeSeriesInsert(time_dataset=time_dataset),
         )
 
     def query_time_array(
@@ -181,6 +188,7 @@ class TimeSeries(Node):
 
         time_series_query_result_get = query_time_series_data.request_sync(
             client=get_client(),
+            project_uuid=str(self.project),
             uuid=str(self.uuid),
             start_time=start_time.to_iso_string(),
             end_time=end_time.to_iso_string(),
@@ -230,7 +238,9 @@ class TimeSeries(Node):
 
     def list_layers(self) -> List[Layer]:
         """Lists all layers into this time series."""
-        time_series_layers = list_time_series_layers.request_sync(client=get_client(), time_series_uuid=str(self.uuid))
+        time_series_layers = list_time_series_layers.request_sync(
+            client=get_client(), project_uuid=str(self.project), time_series_uuid=str(self.uuid)
+        )
 
         # Parse the layers into their final representation.
         unsorted_layers = [Layer.parse_obj(layer.dict()) for layer in time_series_layers.data]
@@ -255,14 +265,17 @@ class TimeSeries(Node):
         )
 
         time_series_run_policy = create_time_series_run_policy.request_sync(
-            client=get_client(), time_series_uuid=str(self.uuid), json_body=time_series_run_policy_create
+            client=get_client(),
+            project_uuid=str(self.project),
+            time_series_uuid=str(self.uuid),
+            json_body=time_series_run_policy_create,
         )
 
         return TimeSeriesRunPolicy.parse_obj(time_series_run_policy.dict())
 
     def list_run_policies(self) -> List[TimeSeriesRunPolicy]:
         time_series_run_policies = list_time_series_run_policies.request_sync(
-            client=get_client(), time_series_uuid=str(self.uuid)
+            client=get_client(), project_uuid=str(self.project), time_series_uuid=str(self.uuid)
         )
 
         return [
